# Employees:
A list of every employee working at the main (internal) company.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Name:
The employee's first and last name.

### Position:
The position of the employee within the company. Positions can be added, edited and deleted by managers under CRM > Administration > Company Positions.

### Primary Relationship Manager:
Displays the primary relationship manager of the employee. Hover over the name to display more information about the person.

### Primary Telephone:
The employee's primary telephone number.

## Legend:
Click on the legend to filter for employees where the main company is their primary employer.

## Filters:

### No Activity:
Filter employees with no activity for x amount of time.

### Primary Email:
Filter employees by their primary email address.

## Search Field:
Typing in the search field allows to filter the employees by name.
